@@ -879,7 +879,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -899,7 +899,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -989,8 +989,8 @@ class attribute02Type(str, Enum):
 class FooList(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('attribute01', 'attribute01Type', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attribute02', 'attribute02Type', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attribute01', 'attribute01Type', 0, 1, {'use': 'optional', 'name': 'attribute01'}),
+        MemberSpec_('attribute02', 'attribute02Type', 0, 1, {'use': 'optional', 'name': 'attribute02'}),
         MemberSpec_('Foo', 'FooType', 0, 0, {'name': 'Foo', 'type': 'FooType'}, None),
         MemberSpec_('Bar', 'BarType', 0, 0, {'name': 'Bar', 'type': 'BarType'}, None),
         MemberSpec_('Baz', 'BazType', 0, 0, {'name': 'Baz', 'type': 'BazType'}, None),
