@@ -879,7 +879,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -899,7 +899,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -980,7 +980,7 @@ def _cast(typ, value):
 class test1element(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('test1attribute', 'cimAnySimpleType', 0, 1, {'use': 'optional'}),
+        MemberSpec_('test1attribute', 'cimAnySimpleType', 0, 1, {'use': 'optional', 'name': 'test1attribute'}),
         MemberSpec_('test1member', 'cimAnySimpleType', 0, 0, {'name': 'test1member', 'type': 'cimAnySimpleType'}, None),
     ]
     subclass = None
