@@ -880,7 +880,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -900,7 +900,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -981,7 +981,7 @@ def _cast(typ, value):
 class myelement(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
-        'href': MemberSpec_('href', 'anyURI', 0, 1, {'use': 'optional'}),
+        'href': MemberSpec_('href', 'anyURI', 0, 1, {'use': 'optional', 'name': 'href'}),
     }
     __slots__ = GeneratedsSuper.gds_subclass_slots(member_data_items_)
     subclass = None
