@@ -94,6 +94,8 @@ $commands = [
   "diff -u anycontent1_sup.py anycontent2_sup.py",
   "diff -u anycontent1_sub.py anycontent2_sub.py",
   "diff -u doc_strings1_sub.py doc_strings2_sub.py",
+  "diff -u recursive_generator_method1_sup.py recursive_generator_method2_sup.py",
+  "diff -u recursive_generator_method1_sub.py recursive_generator_method2_sub.py",
 ]
 
 def check
