@@ -877,7 +877,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -897,7 +897,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1382,10 +1382,10 @@ class DefaultType1(GeneratedsSuper):
 class DefaultType2(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('attrdefault01', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrdefault02', 'xs:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrnormal01', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrnormal02', 'xs:integer', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attrdefault01', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrdefault01'}),
+        MemberSpec_('attrdefault02', 'xs:integer', 0, 1, {'use': 'optional', 'name': 'attrdefault02'}),
+        MemberSpec_('attrnormal01', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrnormal01'}),
+        MemberSpec_('attrnormal02', 'xs:integer', 0, 1, {'use': 'optional', 'name': 'attrnormal02'}),
     ]
     subclass = None
     superclass = None
@@ -1738,10 +1738,10 @@ class FixedType1(GeneratedsSuper):
 class FixedType2(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('attrfixed01', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrfixed02', 'xs:integer', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrnormal01', 'xs:string', 0, 1, {'use': 'optional'}),
-        MemberSpec_('attrnormal02', 'xs:integer', 0, 1, {'use': 'optional'}),
+        MemberSpec_('attrfixed01', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrfixed01'}),
+        MemberSpec_('attrfixed02', 'xs:integer', 0, 1, {'use': 'optional', 'name': 'attrfixed02'}),
+        MemberSpec_('attrnormal01', 'xs:string', 0, 1, {'use': 'optional', 'name': 'attrnormal01'}),
+        MemberSpec_('attrnormal02', 'xs:integer', 0, 1, {'use': 'optional', 'name': 'attrnormal02'}),
     ]
     subclass = None
     superclass = None
