@@ -877,7 +877,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -897,7 +897,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -985,7 +985,7 @@ class USState(str, Enum):
 class PurchaseOrderType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('orderDate', 'date', 0, 1, {'use': 'optional'}),
+        MemberSpec_('orderDate', 'date', 0, 1, {'use': 'optional', 'name': 'orderDate'}),
         MemberSpec_('shipTo', 'Address', 0, 0, {'name': 'shipTo', 'type': 'Address'}, None),
         MemberSpec_('billTo', 'Address', 0, 0, {'name': 'billTo', 'type': 'Address'}, None),
         MemberSpec_('comment', 'string', 0, 1, {'minOccurs': '0', 'name': 'comment', 'ref': 'comment', 'type': 'string'}, None),
@@ -1544,7 +1544,7 @@ class USAddress(Address):
 class UKAddress(Address):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('exportCode', 'positiveInteger', 0, 1, {'use': 'optional'}),
+        MemberSpec_('exportCode', 'positiveInteger', 0, 1, {'use': 'optional', 'name': 'exportCode'}),
         MemberSpec_('postcode', ['UKPostcode', 'string'], 0, 0, {'name': 'postcode', 'type': 'string'}, None),
     ]
     subclass = None
@@ -1678,7 +1678,7 @@ class UKAddress(Address):
 class itemType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('partNum', 'ipo:SKU', 0, 0, {'use': 'required'}),
+        MemberSpec_('partNum', 'ipo:SKU', 0, 0, {'use': 'required', 'name': 'partNum'}),
         MemberSpec_('productName', 'string', 0, 0, {'name': 'productName', 'type': 'string'}, None),
         MemberSpec_('quantity', ['quantityType', 'positiveInteger'], 0, 0, {'name': 'quantity', 'type': 'positiveInteger'}, None),
         MemberSpec_('USPrice', 'decimal', 0, 0, {'name': 'USPrice', 'type': 'decimal'}, None),
