@@ -879,7 +879,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -899,7 +899,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1096,15 +1096,15 @@ class containerType(GeneratedsSuper):
 class tGeoData(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('extraHeight', 'xs:double', 0, 1, {'use': 'optional'}),
-        MemberSpec_('extraData', 'tFloat', 0, 1, {'use': 'optional'}),
-        MemberSpec_('doubleListData', 'tDoubleListRestriction', 0, 0, {'use': 'required'}),
-        MemberSpec_('integerListData', 'tIntegerListRestriction', 0, 1, {'use': 'optional'}),
-        MemberSpec_('floatListData', 'tFloatListRestriction', 0, 1, {'use': 'optional'}),
-        MemberSpec_('dateTimeListData', 'tDateTimeListRestriction', 0, 1, {'use': 'optional'}),
-        MemberSpec_('dateListData', 'tDateListRestriction', 0, 1, {'use': 'optional'}),
-        MemberSpec_('timeListData', 'tTimeListRestriction', 0, 1, {'use': 'optional'}),
-        MemberSpec_('booleanListData', 'tBooleanListRestriction', 0, 1, {'use': 'optional'}),
+        MemberSpec_('extraHeight', 'xs:double', 0, 1, {'use': 'optional', 'name': 'extraHeight'}),
+        MemberSpec_('extraData', 'tFloat', 0, 1, {'use': 'optional', 'name': 'extraData'}),
+        MemberSpec_('doubleListData', 'tDoubleListRestriction', 0, 0, {'use': 'required', 'name': 'doubleListData'}),
+        MemberSpec_('integerListData', 'tIntegerListRestriction', 0, 1, {'use': 'optional', 'name': 'integerListData'}),
+        MemberSpec_('floatListData', 'tFloatListRestriction', 0, 1, {'use': 'optional', 'name': 'floatListData'}),
+        MemberSpec_('dateTimeListData', 'tDateTimeListRestriction', 0, 1, {'use': 'optional', 'name': 'dateTimeListData'}),
+        MemberSpec_('dateListData', 'tDateListRestriction', 0, 1, {'use': 'optional', 'name': 'dateListData'}),
+        MemberSpec_('timeListData', 'tTimeListRestriction', 0, 1, {'use': 'optional', 'name': 'timeListData'}),
+        MemberSpec_('booleanListData', 'tBooleanListRestriction', 0, 1, {'use': 'optional', 'name': 'booleanListData'}),
         MemberSpec_('coordChild', ['tDoubleListRestriction', 'tDoubleList', 'xs:double'], 0, 1, {'maxOccurs': '1', 'minOccurs': '0', 'name': 'coordChild', 'type': 'xs:double'}, None),
     ]
     subclass = None
