@@ -878,7 +878,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -898,7 +898,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1006,7 +1006,7 @@ class RelationType3(str, Enum):
 class SpecialDate(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('SpecialProperty', 'xs:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('SpecialProperty', 'xs:string', 0, 1, {'use': 'optional', 'name': 'SpecialProperty'}),
         MemberSpec_('valueOf_', 'xs:date', 0),
     ]
     subclass = None
@@ -1102,7 +1102,7 @@ class SpecialDate(GeneratedsSuper):
 class ExtremeDate(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('ExtremeProperty', 'xs:string', 0, 1, {'use': 'optional'}),
+        MemberSpec_('ExtremeProperty', 'xs:string', 0, 1, {'use': 'optional', 'name': 'ExtremeProperty'}),
         MemberSpec_('valueOf_', ['RelationType', 'RelationType2', 'RelationType3', 'xs:string'], 0),
     ]
     subclass = None
