@@ -878,7 +878,7 @@ class MixedContainer:
                 self.name,
                 base64.b64encode(self.value),
                 self.name))
-    def to_etree(self, element, mapping_=None, nsmap_=None):
+    def to_etree(self, element, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.category == MixedContainer.CategoryText:
             # Prevent exporting empty content as empty lines.
             if self.value.strip():
@@ -898,7 +898,7 @@ class MixedContainer:
             subelement.text = self.to_etree_simple()
         else:    # category == MixedContainer.CategoryComplex
             self.value.to_etree(element)
-    def to_etree_simple(self, mapping_=None, nsmap_=None):
+    def to_etree_simple(self, mapping_=None, reverse_mapping_=None, nsmap_=None):
         if self.content_type == MixedContainer.TypeString:
             text = self.value
         elif (self.content_type == MixedContainer.TypeInteger or
@@ -1103,8 +1103,8 @@ class simpleTypeTestsType(GeneratedsSuper):
 class simpleContentType(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('lang', 'xs:normalizedString', 0, 1, {'use': 'optional'}),
-        MemberSpec_('identifier', 'xs:normalizedString', 0, 1, {'use': 'optional'}),
+        MemberSpec_('lang', 'xs:normalizedString', 0, 1, {'use': 'optional', 'name': 'lang'}),
+        MemberSpec_('identifier', 'xs:normalizedString', 0, 1, {'use': 'optional', 'name': 'identifier'}),
         MemberSpec_('valueOf_', 'xs:normalizedString', 0),
     ]
     subclass = None
